summaryrefslogtreecommitdiffstats
path: root/qtjava/javalib/test/QTimerTest.java
diff options
context:
space:
mode:
Diffstat (limited to 'qtjava/javalib/test/QTimerTest.java')
-rw-r--r--qtjava/javalib/test/QTimerTest.java108
1 files changed, 54 insertions, 54 deletions
diff --git a/qtjava/javalib/test/QTimerTest.java b/qtjava/javalib/test/QTimerTest.java
index c81c2c70..c364f68b 100644
--- a/qtjava/javalib/test/QTimerTest.java
+++ b/qtjava/javalib/test/QTimerTest.java
@@ -5,7 +5,7 @@
import org.kde.qt.*;
-public class QTimerTest extends QWidget {
+public class TQTimerTest extends TQWidget {
public static final int COLOR_MENU_ID_BLACK = 0;
public static final int COLOR_MENU_ID_RED = 1;
@@ -15,19 +15,19 @@ public class QTimerTest extends QWidget {
public static int eventCount = 0;
- private QMenuBar _menubar;
- private QPopupMenu _filemenu;
- private QPopupMenu _colormenu;
- private QPopupMenu _helpmenu;
- private QScrollView _scrollview;
+ private TQMenuBar _menubar;
+ private TQPopupMenu _filemenu;
+ private TQPopupMenu _colormenu;
+ private TQPopupMenu _helpmenu;
+ private TQScrollView _scrollview;
private ScribbleArea _scribblearea;
- public class ScribbleArea extends QWidget {
- private QPoint _last;
- private QColor _currentcolor;
+ public class ScribbleArea extends TQWidget {
+ private TQPoint _last;
+ private TQColor _currentcolor;
- private QPixmap _buffer;
- private QPopupMenu _popupmenu;
+ private TQPixmap _buffer;
+ private TQPopupMenu _popupmenu;
/**
* The constructor. Initializes the member variables.
@@ -35,24 +35,24 @@ public class QTimerTest extends QWidget {
ScribbleArea()
{
// initialize member variables
- _buffer = new QPixmap();
- _last = new QPoint();
+ _buffer = new TQPixmap();
+ _last = new TQPoint();
_currentcolor = Qt.black();
// don't blank the window before repainting
setBackgroundMode( NoBackground );
// create a pop-up menu
- _popupmenu = new QPopupMenu();
+ _popupmenu = new TQPopupMenu();
_popupmenu.insertItem( "&Clear", this, Qt.SLOT( "slotClearArea()" ) );
}
/**
* This slot sets the curren color for the scribble area. It will be
* connected with the colorChanged( QColor ) signal from the
* ScribbleWindow.
*/
- public void setColor( QColor new_color )
+ public void setColor( TQColor new_color )
{
_currentcolor = new_color;
}
@@ -67,18 +67,18 @@ public class QTimerTest extends QWidget {
_buffer.fill( Qt.white() );
// and copy it over to the window
- QPaintDevice.bitBlt( this, 0, 0, _buffer );
+ TQPaintDevice.bitBlt( this, 0, 0, _buffer );
}
/**
* This method does the actual loading. It relies on QPixmap (and the
* underlying I/O machinery) to determine the filetype.
*/
public void slotLoad( String filename )
{
if ( !_buffer.load( filename ) )
- QMessageBox.warning( null, "Load error", "Could not load file" );
+ TQMessageBox.warning( null, "Load error", "Could not load file" );
repaint(); // refresh the window
}
@@ -91,7 +91,7 @@ public class QTimerTest extends QWidget {
public void slotSave( String filename )
{
if( !_buffer.save( filename, "BMP" ) )
- QMessageBox.warning( null, "Save error", "Could not save file" );
+ TQMessageBox.warning( null, "Save error", "Could not save file" );
}
@@ -100,10 +100,10 @@ public class QTimerTest extends QWidget {
* mouse over the window. It just records the position of the mouse
* at the time of the click.
*/
- public void mousePressEvent(QMouseEvent event)
+ public void mousePressEvent(TQMouseEvent event)
{
if ( event.button() == RightButton )
- _popupmenu.exec( QCursor.pos() );
+ _popupmenu.exec( TQCursor.pos() );
else
{
_last = event.pos(); // retrieve the coordinates from the event
@@ -119,11 +119,11 @@ public class QTimerTest extends QWidget {
* we haven't, and thus don't have to check whether any buttons are
* pressed.
*/
- public void mouseMoveEvent(QMouseEvent event) {
- // create a QPainter object for drawing onto the window
- QPainter windowpainter = new QPainter();
- // and another QPainter object for drawing int an off-screen pixmap
- QPainter bufferpainter = new QPainter();
+ public void mouseMoveEvent(TQMouseEvent event) {
+ // create a TQPainter object for drawing onto the window
+ TQPainter windowpainter = new TQPainter();
+ // and another TQPainter object for drawing int an off-screen pixmap
+ TQPainter bufferpainter = new TQPainter();
// start painting
windowpainter.begin( this ); // this painter paints onto the window
@@ -149,67 +149,67 @@ public class QTimerTest extends QWidget {
* This method is called whenever the widget needs
* painting, for example when it has been obscured and then revealed again.
*/
- public void paintEvent(QPaintEvent event) {
- QPaintDevice.bitBlt(this, 0, 0, _buffer);
+ public void paintEvent(TQPaintEvent event) {
+ TQPaintDevice.bitBlt(this, 0, 0, _buffer);
}
/**
* This method get called whenever the widget needs
* painting, for example, when it has been obscured and then revealed again.
*/
- public void resizeEvent(QResizeEvent event) {
- QPixmap save = new QPixmap( _buffer );
+ public void resizeEvent(TQResizeEvent event) {
+ TQPixmap save = new TQPixmap( _buffer );
_buffer.resize( event.size() );
_buffer.fill( Qt.white() );
- QPaintDevice.bitBlt( _buffer, 0, 0, save );
+ TQPaintDevice.bitBlt( _buffer, 0, 0, save );
}
}
- QTimerTest()
+ TQTimerTest()
{
/* The next lines build the menu bar. We first create the menus
* one by one, then add them to the menu bar. */
- _filemenu = new QPopupMenu(); // create a file menu
+ _filemenu = new TQPopupMenu(); // create a file menu
_filemenu.insertItem( "&Load", this, Qt.SLOT( "slotLoad()" ) );
_filemenu.insertItem( "&Save", this, Qt.SLOT( "slotSave()" ) );
_filemenu.insertSeparator();
_filemenu.insertItem( "&Quit", Qt.qApp(), Qt.SLOT( "quit()" ) );
- _colormenu = new QPopupMenu(); // create a color menu
+ _colormenu = new TQPopupMenu(); // create a color menu
_colormenu.insertItem( "B&lack", COLOR_MENU_ID_BLACK);
_colormenu.insertItem( "&Red", COLOR_MENU_ID_RED);
_colormenu.insertItem( "&Blue", COLOR_MENU_ID_BLUE);
_colormenu.insertItem( "&Green", COLOR_MENU_ID_GREEN);
_colormenu.insertItem( "&Yellow", COLOR_MENU_ID_YELLOW);
- QObject.connect( _colormenu, SIGNAL( "activated(int)" ),
+ TQObject.connect( _colormenu, SIGNAL( "activated(int)" ),
this, SLOT( "slotColorMenu(int)" ) );
- _helpmenu = new QPopupMenu(); // create a help menu
+ _helpmenu = new TQPopupMenu(); // create a help menu
_helpmenu.insertItem( "&About QtScribble", this, SLOT( "slotAbout()" ) );
_helpmenu.insertItem( "&About Qt", this, SLOT( "slotAboutQt()" ) );
- _menubar = new QMenuBar( this, "" ); // create a menu bar
+ _menubar = new TQMenuBar( this, "" ); // create a menu bar
_menubar.insertItem( "&File", _filemenu );
_menubar.insertItem( "&Color", _colormenu );
_menubar.insertItem( "&Help", _helpmenu );
/* We create a QScrollView and a ScribbleArea. The ScribbleArea will
* be managed by the scroll view.*/
- _scrollview = new QScrollView( this );
+ _scrollview = new TQScrollView( this );
_scrollview.setGeometry( 0, _menubar.height(),
width(), height() - _menubar.height() );
_scribblearea = new ScribbleArea();
_scribblearea.setGeometry( 0, 0, 1000, 1000 );
_scrollview.addChild( _scribblearea );
- QObject.connect( this, SIGNAL( "colorChanged(QColor)" ),
- _scribblearea, SLOT( "setColor(QColor)" ) );
- QObject.connect( this, SIGNAL( "save(java.lang.String)" ),
+ TQObject.connect( this, SIGNAL( "colorChanged(TQColor)" ),
+ _scribblearea, SLOT( "setColor(TQColor)" ) );
+ TQObject.connect( this, SIGNAL( "save(java.lang.String)" ),
_scribblearea, SLOT( "slotSave(java.lang.String)" ) );
- QObject.connect( this, SIGNAL( "load(java.lang.String)" ),
+ TQObject.connect( this, SIGNAL( "load(java.lang.String)" ),
_scribblearea, SLOT( "slotLoad(java.lang.String)" ) );
}
- public void resizeEvent( QResizeEvent event )
+ public void resizeEvent( TQResizeEvent event )
{
/* When the whole window is resized, we have to rearrange the geometry
* in the ScribbleWindow as well. Note that the ScribbleArea does not need
@@ -222,7 +222,7 @@ public class QTimerTest extends QWidget {
public void slotAbout()
{
- QMessageBox.information( this, "About QtScribble 5",
+ TQMessageBox.information( this, "About QtScribble 5",
"This is the Scribble 5 application\n" +
"Copyright 1998 by Mathias Kalle Dalheimer\n"
);
@@ -230,7 +230,7 @@ public class QTimerTest extends QWidget {
public void slotAboutQt()
{
- QMessageBox.aboutQt( this, "About Qt" );
+ TQMessageBox.aboutQt( this, "About Qt" );
}
public void slotColorMenu( int item )
@@ -258,7 +258,7 @@ public class QTimerTest extends QWidget {
/**
* This is the slot for the menu item File/Load. It opens a
* QFileDialog to ask the user for a filename, then emits a save()
* signal with the filename as parameter.
*/
public void slotLoad()
@@ -266,14 +266,14 @@ public class QTimerTest extends QWidget {
/* Open a file dialog for loading. The default directory is the
* current directory, the filter *.bmp.
*/
- String filename = QFileDialog.getOpenFileName( ".", "*.bmp", this );
+ String filename = TQFileDialog.getOpenFileName( ".", "*.bmp", this );
if ( !filename.equals("") )
emit("load", filename);
}
/**
* This is the slot for the menu item File/Load. It opens a
* QFileDialog to ask the user for a filename, then emits a save()
* signal with the filename as parameter.
*/
public void slotSave()
@@ -281,7 +281,7 @@ public class QTimerTest extends QWidget {
/* Open a file dialog for saving. The default directory is the
* current directory, the filter *.bmp.
*/
- String filename = QFileDialog.getSaveFileName( ".", "*.bmp", this );
+ String filename = TQFileDialog.getSaveFileName( ".", "*.bmp", this );
if ( !filename.equals("") )
emit("save", filename);
}
@@ -293,11 +293,11 @@ public class QTimerTest extends QWidget {
public static void main(String[] args)
{
- QApplication myapp = new QApplication(args);
- QTimerTest mywidget = new QTimerTest();
+ TQApplication myapp = new TQApplication(args);
+ TQTimerTest mywidget = new TQTimerTest();
mywidget.setGeometry(50, 500, 400, 400);
- QTimer timer = new QTimer( mywidget );
+ TQTimer timer = new TQTimer( mywidget );
connect( timer, Qt.SIGNAL("timeout()"),
mywidget, Qt.SLOT("timerDone()") );
timer.start( 2000, false ); // 2 seconds single-shot
@@ -35,24 +35,24 @@ public class QTimerTest extends QWidget {
/**
* This slot sets the curren color for the scribble area. It will be
- * connected with the colorChanged( QColor ) signal from the
+ * connected with the colorChanged( TQColor ) signal from the
* ScribbleWindow.
*/
@@ -67,18 +67,18 @@ public class QTimerTest extends QWidget {
}
/**
- * This method does the actual loading. It relies on QPixmap (and the
+ * This method does the actual loading. It relies on TQPixmap (and the
* underlying I/O machinery) to determine the filetype.
*/
@@ -149,67 +149,67 @@ public class QTimerTest extends QWidget {
_menubar.insertItem( "&Color", _colormenu );
_menubar.insertItem( "&Help", _helpmenu );
- /* We create a QScrollView and a ScribbleArea. The ScribbleArea will
+ /* We create a TQScrollView and a ScribbleArea. The ScribbleArea will
* be managed by the scroll view.*/
@@ -258,7 +258,7 @@ public class QTimerTest extends QWidget {
/**
* This is the slot for the menu item File/Load. It opens a
- * QFileDialog to ask the user for a filename, then emits a save()
+ * TQFileDialog to ask the user for a filename, then emits a save()
* signal with the filename as parameter.
*/
@@ -266,14 +266,14 @@ public class QTimerTest extends QWidget {
/**
* This is the slot for the menu item File/Load. It opens a
- * QFileDialog to ask the user for a filename, then emits a save()
+ * TQFileDialog to ask the user for a filename, then emits a save()
* signal with the filename as parameter.
*/